@@ -29,8 +29,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/build/python2/src/Python-2.7.12/coverage.info',
- 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.12/lcov-report',
+ 'COVERAGE_INFO': '/build/python2/src/Python-2.7.13/coverage.info',
+ 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.13/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -D_FORTIFY_SOURCE=2',
  'CXX': 'g++ -pthread',
@@ -231,7 +231,6 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
- 'HAVE_RAND_EGD': 1,
  'HAVE_READLINK': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RL_CALLBACK': 1,
@@ -467,7 +466,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.12',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.13',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -511,7 +510,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.12 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.13 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -536,10 +535,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python2/src/Python-2.7.12',
- 'abs_srcdir': '/build/python2/src/Python-2.7.12',
+ 'abs_builddir': '/build/python2/src/Python-2.7.13',
+ 'abs_srcdir': '/build/python2/src/Python-2.7.13',
  'build': 'armv5tel-unknown-linux-gnueabi',
- 'cross_compiling': 'no',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'host': 'armv5tel-unknown-linux-gnueabi',
